#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 Glob
version:              0.10.1
visibility:           public
id:                   Glob-0.10.1-4GQgpbyIjcQ4yYCoQ2ZkFz
key:                  Glob-0.10.1-4GQgpbyIjcQ4yYCoQ2ZkFz
license:              BSD-3-Clause
maintainer:           Matti Niemenmaa <matti.niemenmaa+glob@iki.fi>
author:               Matti Niemenmaa
stability:            provisional
homepage:             http://iki.fi/matti.niemenmaa/glob/
synopsis:             Globbing library
description:
    A library for globbing: matching patterns against file paths.

category:             System
abi:                  2c91bac49190d53e1f83d70ecae4dcaf
exposed:              True
exposed-modules:      System.FilePath.Glob System.FilePath.Glob.Primitive
hidden-modules:
    System.FilePath.Glob.Base System.FilePath.Glob.Directory
    System.FilePath.Glob.Match System.FilePath.Glob.Simplify
    System.FilePath.Glob.Utils

import-dirs:          /usr/lib/ghc-8.10.5/site-local/Glob-0.10.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/Glob-0.10.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/Glob-0.10.1
hs-libraries:         HSGlob-0.10.1-4GQgpbyIjcQ4yYCoQ2ZkFz
depends:
    base-4.14.2.0 containers-0.6.4.1 directory-1.3.6.0
    dlist-1.0-AY7L3vPTTCQEIACGjuCugq filepath-1.4.2.1
    transformers-0.5.6.2
    transformers-compat-0.6.6-8xD7tdhdla21VYsnm1hEvk

haddock-interfaces:   /usr/share/doc/haskell-glob/html/Glob.haddock
haddock-html:         /usr/share/doc/haskell-glob/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

